Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterValidator ¶
func RegisterValidator(name string, handler ValidatorHandler)
RegisterValidator maps a validator by name to a corrosponding handler. These handlers should not mutate any global data as these handlers run in parallel.
Types ¶
type ValidatorHandler ¶
type ValidatorHandler func(reflect.StructField, reflect.Value) error
Click to show internal directories.
Click to hide internal directories.